@@ -1,4 +1,9 @@
+from __future__ import print_function
+
 import os
+import shutil
+import sys
+
 try:
     import configparser
 except ImportError:
@@ -14,6 +19,15 @@ class Configuration(object):
     }
 
     def __init__(self, topdir):
+        self.topdir = topdir
+        self.saladir = os.path.join(topdir, '.sala')
+        self.keyfile = os.path.join(self.saladir, 'key')
+        self.hooksdir = os.path.join(self.saladir, 'hooks')
+
+        # Backwards compatibility migrations
+        self.compat('sala.conf', 'config')
+        self.compat('.salakey', 'key')
+
         self.parser = configparser.RawConfigParser()
 
         self.parser.add_section('sala')
@@ -27,14 +41,11 @@ class Configuration(object):
         config_files = [
             os.path.expanduser('~/.sala.conf'),
             os.path.join(xdg_config_home, 'sala.conf'),
-            os.path.join(topdir, 'sala.conf'),
+            os.path.join(topdir, '.sala', 'config'),
         ]
 
         self.parser.read(config_files)
 
-        self.topdir = topdir
-        self.keyfile = os.path.join(topdir, '.salakey')
-
     def __getattr__(self, key):
         # Proxies ConfigParser getters like this:
         #
@@ -45,3 +56,18 @@ class Configuration(object):
             raise AttributeError(key)
 
         return lambda x: getattr(self.parser, key)('sala', x)
+
+    def compat(self, old, new):
+        # Rename old to .sala/new if old exists and .sala/new does not
+
+        old = os.path.join(self.topdir, old)
+        new = os.path.join(self.saladir, new)
+
+        if os.path.exists(old) and not os.path.exists(new):
+            if not os.path.exists(self.saladir):
+                print('NOTE: Creating directory %s' % self.saladir,
+                      file=sys.stderr)
+                os.mkdir(self.saladir)
+
+            print('NOTE: Moving %s to %s' % (old, new))
+            shutil.move(old, new)
